@@ -4,6 +4,8 @@ from django.conf import settings
 from django.contrib.sites.models import Site
 
 from planet.forms import SearchForm
+from planet.settings import PLANET_CONFIG
+
 
 def context(request):
     if request.method == "GET" and request.GET.get("search"):
@@ -13,7 +15,5 @@ def context(request):
 
     site = Site.objects.get(pk=settings.SITE_ID)
 
-    return {"site": site,
-        "SITE_NAME": site.name,
-        "search_form": search_form}
-
+    return {"site": site, "SITE_NAME": site.name,
+        "search_form": search_form, "PLANET_CONFIG": PLANET_CONFIG}
